c
c Home directory
c
      character homedir*(*)
      Parameter ( homedir = '/home/masunaga/SDSimulator/' )
c      
c Grid dimensions
c
      Include 'GRIDparameters.inc'
c
c  ######## microwave radiometer #######
c
c mxfreq : The number of channels
c                          
      integer    mxfreq
      parameter  (mxfreq = 5)
c
c - The following variables are defined in "param_set.f"
c
c freq  : Channel frequencies in [GHz]
c
      real *4 freq(mxfreq)
c
c inc_angle_mwr : viewing angle in [deg]
c
      real *4 inc_angle_mwr
c
c  ############## radar ###############
c
c mxfreq_radar : The number of channels
c                          
      integer mxfreq_radar
      Parameter (mxfreq_radar = 1)
c
c - The following variables are defined in "param_set.f"
c
c freq_radar : Channel frequencies in [GHz]
c
      real *4 freq_radar(mxfreq_radar)
c
c inc_angle_rdr : viewing angle in [deg]
c
      real *4 inc_angle_rdr
c
c  ######## visible/IR imager ##########
c
c mxwavel : The number of channels
c                          
      integer mxwavel
      parameter(mxwavel = 5)
c
c - The following variables are defined in "param_set.f"
c
c wavel : Channel wavelengths in [micron]
c
      real *4 wavel(mxwavel)
c
c znth_slr : solar zenith angle in [deg]
c znth_obs : veiwing zenith angle in [deg]
c azmth    : azimuth angle between the sun and sensor [deg]
c
      real *4 znth_slr,znth_obs,azmth
c
c ###### input model definitions ######
c
c CRM file list
c
c nmodel : The number of input model
c
      integer   nmodel
      parameter ( nmodel = 4 )
c
c CRM_file_list : Input file names, defined in "def_file_list.f".
c
      character CRM_file_list(nmodel)*90
c
c ########## running options ##########
c
c umu : Direction cosine (assigned automatically)
c
      real *4  umu
c
c - The following variables are defined in "param_set.f"
c
c microw : microwave simulator switch; on (off) when .true. (.false.)
c radar  : radar simulator switch    ; on (off) when .true. (.false.)
c visIR  : visble/IR simulator switch; on (off) when .true. (.false.)
c
      logical    microw, radar, visIR
c
c lut        : =.true. for using the Mie LUTs for microwave
c                      and radar simulations
c slant_path : =.true. for the slant-path option for microwave RT.
c                      (otherwise the plane-parallel option is selected.)
c
      logical    lut, slant_path
c
c background : "water" or "land" to specify the surface condition
c 
      character  background*5
c
c ######## cloud model variables #########
c
c Input geophysical parameters and their grid dimensions.
c See "rd_CRM.f" for descriptions of individual variables.
c
      integer    ngridx, ngridy, nlyr
      real *4    deltax, deltay
      real *4           tskin(mxgridx,mxgridy)
      integer             ics(mxgridx,mxgridy)
      real *4    rainrate_sfc(mxgridx,mxgridy)
      real *4        wind_sfc(mxgridx,mxgridy)
      real *4         soilH2O(mxgridx,mxgridy)
      real *4         hgt_lev(0:mxlyr)
      real *4       press_lev(mxgridx,mxgridy,0:mxlyr)
      real *4        temp_lev(mxgridx,mxgridy,0:mxlyr)
      real *4        wind_lev(mxgridx,mxgridy,0:mxlyr)
      real *4      relhum_avg(mxgridx,mxgridy,mxlyr)
      real *4 cloud_water_avg(mxgridx,mxgridy,mxlyr)
      real *4        rain_avg(mxgridx,mxgridy,mxlyr)
      real *4   cloud_ice_avg(mxgridx,mxgridy,mxlyr)
      real *4        snow_avg(mxgridx,mxgridy,mxlyr)
      real *4     graupel_avg(mxgridx,mxgridy,mxlyr)
      real *4        hail_avg(mxgridx,mxgridy,mxlyr)
      real *4    avg_pressure(mxgridx,mxgridy,mxlyr)
      real *4 avg_H2Opressure(mxgridx,mxgridy,mxlyr)
c
c ########### output parameters #############
c
c microwave Tb
c
c Tb_out : Microwave brightness temperature in [K]
c   (  The last dimension (0:1) defines horizontal and vertical 
c      polarizations in this order. )
c
      real *4  Tb_out(mxgridx,mxgridy,mxfreq,0:1)
c
c radar Z and PIA
c
c dBZ_out : Radar reflectivity in [dBZ]
c PIA_out : Two-way path-integrated attenuation [dB]
c
      real *4 dBZ_out(mxfreq_radar,mxgridx,mxgridy,mxlyr)
      real *4 PIA_out(mxfreq_radar,mxgridx,mxgridy)
c
c vis/IR radiance
c
c I_visIR : radiance in [W/m2/str/micron] for visible and near-IR
c           wavelengths, and brightness temperature in [K] for
c           thermal infrared wavelengths (>10 micron)
c  
      real *4 I_visIR(mxgridx,mxgridy,mxwavel)
c
c ############## I/O paths ################
c
c CRMdir    : Input CRM directory 
c outputdir : Output directory 
c
      character outputdir*(*),CRMdir*(*)
      parameter ( CRMdir = homedir//'CRM/' )
      parameter ( outputdir = homedir//'outputs/' )
c
c ######### Mie LUT parameters #############
c
c mxpts_temp  : LUT dimension for temperature
c mxpts_hydro : LUT dimension for hydrometeor
c ( mxpts_temp and mxpts_hydro should be equal to or larger than
c   npts_temp and npts_hydro, respectively, as defined in the LUTs. )
c
      Integer mxpts_temp,mxpts_hydro
      parameter (mxpts_temp = 12, mxpts_hydro = 37)
c
c pts_hydro  : LUT hydrometeor vector (in [g/m3])
c pts_temp_w : LUT temperature vector (in [K]) for liquid hydrometeors
c pts_temp_i : LUT temperature vector (in [K]) for frozen hydrometeors
c ( These parameters will be read in from the LUTs. )
c
      real *4 pts_hydro(mxpts_hydro)
      real *4 pts_temp_w(mxpts_temp), pts_temp_i(mxpts_temp)
c
c lutdir     : Directory path for the Mie LUTs
c
      Character lutdir*(*)
      Parameter (lutdir = homedir//'Mie-table/')
