      Subroutine SIMmicro ( lut, slant_path, background, freq, umu,
     &                      press_lev, temp_lev, tskin, wind_sfc, 
     &                      soilH2O, wind_lev, hgt_lev, relhum_avg, 
     &                      avg_pressure, avg_H2Opressure, 
     &                      cloud_water_avg, rain_avg, cloud_ice_avg, 
     &                      snow_avg, graupel_avg, hail_avg, ics,
     &                      ngridx, ngridy, nlyr, deltax, deltay,
     &                      Tb_out )
      Implicit NONE
c
c This subroutine, called by "../RTSIM.f", is the core routine for
c microwave radiometer simulation. 
c
c Inputs:
c  - Running options
c     lut, slant_path, background
c  - Sensor parameters
c     freq, umu
c  - Geophysical parameters
c     press_lev, temp_lev, tskin, wind_sfc, soilH2O, wind_lev (not in use), 
c     hgt_lev, relhum_avg, avg_pressure, avg_H2Opressure, cloud_water_avg, 
c     rain_avg, cloud_ice_avg, snow_avg, graupel_avg, hail_avg, ics
c  - Model spatial dimensions
c     ngridx, ngridy, nlyr, deltax, deltay
c Output:
c     Tb_out
c
      Include '../MAINparameters.inc'
c
      real *4 kextrr_lut_nf(mxpts_temp, mxpts_hydro, mxfreq) 
      real *4 salbrr_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 asymrr_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 kextci_lut_nf(mxpts_temp, mxpts_hydro, mxfreq) 
      real *4 salbci_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 asymci_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 kextcw_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 salbcw_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 asymcw_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 kexthl_lut_nf(mxpts_temp, mxpts_hydro, mxfreq) 
      real *4 salbhl_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 asymhl_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 kextsn_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 salbsn_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 asymsn_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 kextgr_lut_nf(mxpts_temp, mxpts_hydro, mxfreq) 
      real *4 salbgr_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 asymgr_lut_nf(mxpts_temp, mxpts_hydro, mxfreq)
      real *4 kextml_lut_nf(mxpts_hydro, mxfreq) 
      real *4 salbml_lut_nf(mxpts_hydro, mxfreq)
      real *4 asymml_lut_nf(mxpts_hydro, mxfreq)
      real *4 kextci_lut(mxpts_temp, mxpts_hydro) 
      real *4 salbci_lut(mxpts_temp, mxpts_hydro)
      real *4 asymci_lut(mxpts_temp, mxpts_hydro)
      real *4 kextcw_lut(mxpts_temp, mxpts_hydro)
      real *4 salbcw_lut(mxpts_temp, mxpts_hydro)
      real *4 asymcw_lut(mxpts_temp, mxpts_hydro)
      real *4 kexthl_lut(mxpts_temp, mxpts_hydro) 
      real *4 salbhl_lut(mxpts_temp, mxpts_hydro)
      real *4 asymhl_lut(mxpts_temp, mxpts_hydro)
      real *4 kextrr_lut(mxpts_temp, mxpts_hydro) 
      real *4 salbrr_lut(mxpts_temp, mxpts_hydro)
      real *4 asymrr_lut(mxpts_temp, mxpts_hydro)
      real *4 kextsn_lut(mxpts_temp, mxpts_hydro)
      real *4 salbsn_lut(mxpts_temp, mxpts_hydro)
      real *4 asymsn_lut(mxpts_temp, mxpts_hydro)
      real *4 kextgr_lut(mxpts_temp, mxpts_hydro) 
      real *4 salbgr_lut(mxpts_temp, mxpts_hydro)
      real *4 asymgr_lut(mxpts_temp, mxpts_hydro)
      real *4 kextml_lut(mxpts_hydro) 
      real *4 salbml_lut(mxpts_hydro)
      real *4 asymml_lut(mxpts_hydro)
      Integer npts_temp,npts_hydro
c
c Radiative quantities
c
      ! Internal variables
      real *4 tavg, tavg_c, Pres
      real *4 atm_ext(mxgridx,mxgridy,mxlyr)
      real *4 kextcw(mxgridx,mxgridy,mxlyr)
      real *4 salbcw(mxgridx,mxgridy,mxlyr)
      real *4 asymcw(mxgridx,mxgridy,mxlyr)
      real *4 kextrr(mxgridx,mxgridy,mxlyr)
      real *4 salbrr(mxgridx,mxgridy,mxlyr)
      real *4 asymrr(mxgridx,mxgridy,mxlyr)
      real *4 kextci(mxgridx,mxgridy,mxlyr)
      real *4 salbci(mxgridx,mxgridy,mxlyr)
      real *4 asymci(mxgridx,mxgridy,mxlyr)
      real *4 kextsn(mxgridx,mxgridy,mxlyr)
      real *4 salbsn(mxgridx,mxgridy,mxlyr) 
      real *4 asymsn(mxgridx,mxgridy,mxlyr)
      real *4 kextgr(mxgridx,mxgridy,mxlyr)
      real *4 salbgr(mxgridx,mxgridy,mxlyr)
      real *4 asymgr(mxgridx,mxgridy,mxlyr)
      real *4 kexthl(mxgridx,mxgridy,mxlyr)
      real *4 salbhl(mxgridx,mxgridy,mxlyr)
      real *4 asymhl(mxgridx,mxgridy,mxlyr)
      real *4 kextml(mxgridx,mxgridy,mxlyr)
      real *4 salbml(mxgridx,mxgridy,mxlyr)
      real *4 asymml(mxgridx,mxgridy,mxlyr)
      real *4 kexttot(mxgridx,mxgridy,mxlyr)
      real *4 salbtot(mxgridx,mxgridy,mxlyr)
      real *4 asymtot(mxgridx,mxgridy,mxlyr)
      real *4 pbckcw(mxgridx,mxgridy,mxlyr)
      real *4 pbckrr(mxgridx,mxgridy,mxlyr)
      real *4 pbckci(mxgridx,mxgridy,mxlyr)
      real *4 pbcksn(mxgridx,mxgridy,mxlyr)
      real *4 pbckgr(mxgridx,mxgridy,mxlyr)
      real *4 pbckhl(mxgridx,mxgridy,mxlyr)
      real *4 pbckml(mxgridx,mxgridy,mxlyr)
      real *4 kextml0,salbml0,asymml0,pbckml0
c
      logical    lambert
      real *4    freqcy
c
      real *4  emis(mxgridx,mxgridy)
      real *4  ebar(mxgridx,mxgridy)
      real *4  Tb(mxgridx,mxgridy)
c
      real *4 kext_hyd,f_frz
      real *4 pi 
      integer nzfrz(mxgridx,mxgridy)
      Logical intplut
c
c Simplified treatment of melting particles
c
      Parameter ( pi = 3.1415926536 )
      ! internal loop counters
      integer    i, j, k, l, m, nx, ny, nz
      integer    ix, iy, nf, npol
      character*1  POL(0:1)
      data (POL(npol),npol=0,1) / 'H', 'V' /
c
      Character*100 pathandfile
      Real *4 bscaR
c     
c Read Mie lookup table.
c
      If ( lut ) Call open_lut_mwr(
     $                    kextci_lut_nf,salbci_lut_nf,asymci_lut_nf,
     &                    kextcw_lut_nf,salbcw_lut_nf,asymcw_lut_nf,
     &                    kextrr_lut_nf,salbrr_lut_nf,asymrr_lut_nf,
     &                    kextsn_lut_nf,salbsn_lut_nf,asymsn_lut_nf,
     &                    kextgr_lut_nf,salbgr_lut_nf,asymgr_lut_nf,
     &                    kexthl_lut_nf,salbhl_lut_nf,asymhl_lut_nf,
     &                    kextml_lut_nf,salbml_lut_nf,asymml_lut_nf,
     &                    pts_temp_w, pts_temp_i, pts_hydro,
     &                    npts_temp, npts_hydro )
c
c Identify the freezing level
c
      do nx = 1,ngridx
         do ny = 1,ngridy
            do nz = 1,nlyr
               If (temp_lev(nx,ny,nz-1).ge.273.16 .and.
     &             temp_lev(nx,ny,nz)  .le.273.16) then
                  nzfrz(nx,ny) = nz
                  Goto 22
               Endif
            end do
 22      end do
      end do
c
      do nf = 1, mxfreq
        write(*,*) 'Microwave Tb simulation --------'
        freqcy = freq(nf)
        write(*,*) ' nfreq: ',nf,' at',freqcy,' GHz'
c
        Do i = 1 , mxpts_temp
         Do j = 1 , mxpts_hydro
            kextrr_lut(i,j) = kextrr_lut_nf(i,j,nf)
            kextci_lut(i,j) = kextci_lut_nf(i,j,nf)
            kextcw_lut(i,j) = kextcw_lut_nf(i,j,nf)
            kextsn_lut(i,j) = kextsn_lut_nf(i,j,nf)
            kextgr_lut(i,j) = kextgr_lut_nf(i,j,nf)
            kexthl_lut(i,j) = kexthl_lut_nf(i,j,nf)
            salbrr_lut(i,j) = salbrr_lut_nf(i,j,nf)
            salbci_lut(i,j) = salbci_lut_nf(i,j,nf)
            salbcw_lut(i,j) = salbcw_lut_nf(i,j,nf)
            salbsn_lut(i,j) = salbsn_lut_nf(i,j,nf)
            salbgr_lut(i,j) = salbgr_lut_nf(i,j,nf)
            salbhl_lut(i,j) = salbhl_lut_nf(i,j,nf)
            asymrr_lut(i,j) = asymrr_lut_nf(i,j,nf)
            asymci_lut(i,j) = asymci_lut_nf(i,j,nf)
            asymcw_lut(i,j) = asymcw_lut_nf(i,j,nf)
            asymsn_lut(i,j) = asymsn_lut_nf(i,j,nf)
            asymgr_lut(i,j) = asymgr_lut_nf(i,j,nf)
            asymhl_lut(i,j) = asymhl_lut_nf(i,j,nf)
         End do
        End do
        Do j = 1 , mxpts_hydro
            kextml_lut(j) = kextml_lut_nf(j,nf)
            salbml_lut(j) = salbml_lut_nf(j,nf)
            asymml_lut(j) = asymml_lut_nf(j,nf)
        End do
c
c Calculate optical properties of each volume element of the cloud. 
c
        do 110 nx = 1, ngridx
         do 110 ny = 1, ngridy
          f_frz = (temp_lev(nx,ny,nzfrz(nx,ny)-1) - 273.16) /
     &            (temp_lev(nx,ny,nzfrz(nx,ny)-1) - 
     &             temp_lev(nx,ny,nzfrz(nx,ny)))
          do 120 nz = 1, nlyr

            Tavg = 0.5*(temp_lev(nx,ny,nz-1)+temp_lev(nx,ny,nz))
            Tavg_c = Tavg - 273.16
            Pres =
     +          (press_lev(nx,ny,nz) - press_lev(nx,ny,nz-1) )/
     +           log(press_lev(nx,ny,nz)/press_lev(nx,ny,nz-1))
c
c Gas absorption code updated (11/06/03), provided by Chris.
c           
            call absorb(freqcy, Tavg, Pres,
     +                  relhum_avg(nx,ny,nz), 0., atm_ext(nx,ny,nz))
c
c initialization
c
            kextrr(nx,ny,nz) = 0.
            salbrr(nx,ny,nz) = 0.
            asymrr(nx,ny,nz) = 0.
            
            kextci(nx,ny,nz) = 0.
            salbci(nx,ny,nz) = 0.
            asymci(nx,ny,nz) = 0.

            kextcw(nx,ny,nz) = 0.
            salbcw(nx,ny,nz) = 0.
            asymcw(nx,ny,nz) = 0.

            kextsn(nx,ny,nz) = 0.
            salbsn(nx,ny,nz) = 0.
            asymsn(nx,ny,nz) = 0.

            kextgr(nx,ny,nz) = 0.
            salbgr(nx,ny,nz) = 0.
            asymgr(nx,ny,nz) = 0.

            kexthl(nx,ny,nz) = 0.
            salbhl(nx,ny,nz) = 0.
            asymhl(nx,ny,nz) = 0.
c
            If ( lut ) then
c
c Read LUT
c
            Call mie_lut (Tavg,rain_avg(nx,ny,nz),
     &                    kextrr_lut,salbrr_lut,asymrr_lut,
     &                    pts_temp_w, pts_hydro,
     &                    npts_temp, npts_hydro,
     &                    mxpts_temp, mxpts_hydro,
     &                    kextrr(nx,ny,nz),salbrr(nx,ny,nz),
     &                    asymrr(nx,ny,nz))
c
            Call mie_lut (Tavg,cloud_ice_avg(nx,ny,nz),
     &                    kextci_lut,salbci_lut,asymci_lut,
     &                    pts_temp_i, pts_hydro,
     &                    npts_temp, npts_hydro,
     &                    mxpts_temp, mxpts_hydro,
     &                    kextci(nx,ny,nz),salbci(nx,ny,nz),
     &                    asymci(nx,ny,nz))
c
            Call mie_lut (Tavg,cloud_water_avg(nx,ny,nz),
     &                    kextcw_lut,salbcw_lut,asymcw_lut,
     &                    pts_temp_w, pts_hydro,
     &                    npts_temp, npts_hydro,
     &                    mxpts_temp, mxpts_hydro,
     &                    kextcw(nx,ny,nz),salbcw(nx,ny,nz),
     &                    asymcw(nx,ny,nz))
c
            Call mie_lut (Tavg,snow_avg(nx,ny,nz),
     &                    kextsn_lut,salbsn_lut,asymsn_lut,
     &                    pts_temp_i, pts_hydro,
     &                    npts_temp, npts_hydro,
     &                    mxpts_temp, mxpts_hydro,
     &                    kextsn(nx,ny,nz),salbsn(nx,ny,nz),
     &                    asymsn(nx,ny,nz))
c
            Call mie_lut (Tavg,graupel_avg(nx,ny,nz),
     &                    kextgr_lut,salbgr_lut,asymgr_lut,
     &                    pts_temp_i, pts_hydro,
     &                    npts_temp, npts_hydro,
     &                    mxpts_temp, mxpts_hydro,
     &                    kextgr(nx,ny,nz),salbgr(nx,ny,nz),
     &                    asymgr(nx,ny,nz))
c
            Call mie_lut (Tavg,hail_avg(nx,ny,nz),
     &                    kexthl_lut,salbhl_lut,asymhl_lut,
     &                    pts_temp_i, pts_hydro,
     &                    npts_temp, npts_hydro,
     &                    mxpts_temp, mxpts_hydro,
     &                    kexthl(nx,ny,nz),salbhl(nx,ny,nz),
     &                    asymhl(nx,ny,nz))
c
c In case without LUT
c
            Else
c
            call mie_clw_bs(freqcy, Tavg, cloud_water_avg(nx,ny,nz), 
     $                  kextcw(nx,ny,nz), salbcw(nx,ny,nz), 
     $                  asymcw(nx,ny,nz), pbckcw(nx,ny,nz))
c
            call mie_rain_bs(freqcy, Tavg, rain_avg(nx,ny,nz),
     $                   kextrr(nx,ny,nz), salbrr(nx,ny,nz), 
     $                   asymrr(nx,ny,nz), pbckrr(nx,ny,nz), bscaR)
c
            call mie_ci_bs( freqcy, Tavg, cloud_ice_avg(nx,ny,nz),
     $                   kextci(nx,ny,nz), salbci(nx,ny,nz), 
     $                   asymci(nx,ny,nz), pbckci(nx,ny,nz))
c
            call mie_snow_bs( freqcy, Tavg, snow_avg(nx,ny,nz), 
     $                   kextsn(nx,ny,nz), salbsn(nx,ny,nz), 
     $                   asymsn(nx,ny,nz), pbcksn(nx,ny,nz))
c
            call mie_graup_bs( freqcy, Tavg, graupel_avg(nx,ny,nz), 
     $                   kextgr(nx,ny,nz), salbgr(nx,ny,nz), 
     $                   asymgr(nx,ny,nz), pbckgr(nx,ny,nz))
c
            call mie_hail_bs( freqcy, Tavg, hail_avg(nx,ny,nz),
     $                   kexthl(nx,ny,nz), salbhl(nx,ny,nz), 
     $                   asymhl(nx,ny,nz), pbckhl(nx,ny,nz))
c
            Endif
c
c Sum up the absorption/scattering parameters
c
            kext_hyd = kextcw(nx,ny,nz) + kextrr(nx,ny,nz) + 
     &                 kextci(nx,ny,nz) + kextsn(nx,ny,nz) + 
     &                 kextgr(nx,ny,nz) + kexthl(nx,ny,nz)
c
            kexttot(nx,ny,nz)  = atm_ext(nx,ny,nz) + kext_hyd
C     
            if ( kexttot(nx,ny,nz) .le. 0. ) then
              salbtot(nx,ny,nz) = 0.0
            else
              salbtot(nx,ny,nz) = (salbcw(nx,ny,nz)*kextcw(nx,ny,nz) + 
     +                             salbrr(nx,ny,nz)*kextrr(nx,ny,nz) + 
     +                             salbci(nx,ny,nz)*kextci(nx,ny,nz) + 
     +                             salbsn(nx,ny,nz)*kextsn(nx,ny,nz) + 
     +                             salbgr(nx,ny,nz)*kextgr(nx,ny,nz) +
     +                             salbhl(nx,ny,nz)*kexthl(nx,ny,nz)) / 
     +                             kexttot(nx,ny,nz)
            endif
c              
            if ( salbtot(nx,ny,nz) .le. 0.0 ) then
              asymtot(nx,ny,nz) = 0.0
            else
              asymtot(nx,ny,nz) = 
     +          (asymcw(nx,ny,nz)*salbcw(nx,ny,nz)*kextcw(nx,ny,nz) +
     +           asymrr(nx,ny,nz)*salbrr(nx,ny,nz)*kextrr(nx,ny,nz) + 
     +           asymci(nx,ny,nz)*salbci(nx,ny,nz)*kextci(nx,ny,nz) +  
     +           asymsn(nx,ny,nz)*salbsn(nx,ny,nz)*kextsn(nx,ny,nz) + 
     +           asymgr(nx,ny,nz)*salbgr(nx,ny,nz)*kextgr(nx,ny,nz) +
     +           asymhl(nx,ny,nz)*salbhl(nx,ny,nz)*kexthl(nx,ny,nz)) /
     +           (salbtot(nx,ny,nz)*kexttot(nx,ny,nz))
            endif
 120     Continue
c
c simplified treatment of melting particles
c only for stratiform rain
c
         If ( ics(nx,ny) .eq. 2 .and. nzfrz(nx,ny).gt.1 ) then
c
         Do 130 nz = nzfrz(nx,ny)-1, nzfrz(nx,ny)
c
            kextml(nx,ny,nz) = 0.
            salbml(nx,ny,nz) = 0.
            asymml(nx,ny,nz) = 0.
c
            If ( lut ) then
c
            Call mie_lut (273.,rain_avg(nx,ny,nz)+snow_avg(nx,ny,nz),
     &                    kextml_lut,salbml_lut,asymml_lut,
     &                    273.,pts_hydro,
     &                    1,npts_hydro,1,mxpts_hydro,
     &                    kextml0,salbml0,asymml0)
c              
            Else
c
            Call df_mie_melt(freq(nf), Tavg, rain_avg(nx,ny,nz),
     &                       snow_avg(nx,ny,nz),
     &                       kextml0,asymml0,salbml0,pbckml0)
c
            Endif
c
            If ( nz .eq. nzfrz(nx,ny) ) then
               kextml(nx,ny,nz) = f_frz*kextml0 + (1.-f_frz)*
     &                  (kextrr(nx,ny,nz) + kextsn(nx,ny,nz))
               If ( kextml(nx,ny,nz) .gt. 1.e-20)
     &         salbml(nx,ny,nz) = (f_frz*salbml0*kextml0 + (1.-f_frz)*
     &              (salbrr(nx,ny,nz)*kextrr(nx,ny,nz) + 
     &               salbsn(nx,ny,nz)*kextsn(nx,ny,nz))) / 
     &                                kextml(nx,ny,nz)
               If ( salbml(nx,ny,nz) .gt. 1.e-20 ) 
     &         asymml(nx,ny,nz) = 
     &              (f_frz*asymml0*salbml0*kextml0 + (1.-f_frz)*
     &          (asymrr(nx,ny,nz)*salbrr(nx,ny,nz)*kextrr(nx,ny,nz) + 
     &           asymsn(nx,ny,nz)*salbsn(nx,ny,nz)*kextsn(nx,ny,nz)))
     &                         / (salbml(nx,ny,nz)*kextml(nx,ny,nz))
            Endif
            If ( nz .eq. nzfrz(nx,ny)-1 ) then
               kextml(nx,ny,nz) = (1.-f_frz)*kextml0 + f_frz*
     &                  (kextrr(nx,ny,nz) + kextsn(nx,ny,nz))
               If ( kextml(nx,ny,nz) .gt. 1.e-20)
     &         salbml(nx,ny,nz) = ((1.-f_frz)*salbml0*kextml0 + f_frz*
     &              (salbrr(nx,ny,nz)*kextrr(nx,ny,nz) + 
     &               salbsn(nx,ny,nz)*kextsn(nx,ny,nz))) / 
     &                                kextml(nx,ny,nz)
               If ( salbml(nx,ny,nz) .gt. 1.e-20 ) 
     &         asymml(nx,ny,nz) = 
     &              ((1.-f_frz)*asymml0*salbml0*kextml0 + f_frz*
     &          (asymrr(nx,ny,nz)*salbrr(nx,ny,nz)*kextrr(nx,ny,nz) + 
     &           asymsn(nx,ny,nz)*salbsn(nx,ny,nz)*kextsn(nx,ny,nz)))
     &                         / (salbml(nx,ny,nz)*kextml(nx,ny,nz))
            Endif
c
            kexttot(nx,ny,nz) = atm_ext(nx,ny,nz) + kextml(nx,ny,nz) +
     &                          kextcw(nx,ny,nz) + kextci(nx,ny,nz) +
     &                          kextgr(nx,ny,nz) + kexthl(nx,ny,nz)
            If (kexttot(nx,ny,nz) .gt. 0.) then
              salbtot(nx,ny,nz) = (salbcw(nx,ny,nz)*kextcw(nx,ny,nz) + 
     &                             salbci(nx,ny,nz)*kextci(nx,ny,nz) + 
     &                             salbml(nx,ny,nz)*kextml(nx,ny,nz) + 
     &                             salbgr(nx,ny,nz)*kextgr(nx,ny,nz) +
     &                             salbhl(nx,ny,nz)*kexthl(nx,ny,nz)) / 
     &                             kexttot(nx,ny,nz)
c keep the single scattering albedo bound within 0 and 1.
              salbtot(nx,ny,nz) = min(salbtot(nx,ny,nz), 0.999999)
              salbtot(nx,ny,nz) = max(salbtot(nx,ny,nz), 0.)
            Endif
            If (salbtot(nx,ny,nz) .gt. 0.) then
              asymtot(nx,ny,nz) = 
     &          (asymcw(nx,ny,nz)*salbcw(nx,ny,nz)*kextcw(nx,ny,nz) +
     &           asymci(nx,ny,nz)*salbci(nx,ny,nz)*kextci(nx,ny,nz) +  
     &           asymml(nx,ny,nz)*salbml(nx,ny,nz)*kextml(nx,ny,nz) +
     &           asymgr(nx,ny,nz)*salbgr(nx,ny,nz)*kextgr(nx,ny,nz) +
     &           asymhl(nx,ny,nz)*salbhl(nx,ny,nz)*kexthl(nx,ny,nz)) /
     &           (salbtot(nx,ny,nz)*kexttot(nx,ny,nz))
c keep the asymmetry factor boumd within -1 and 1.
              asymtot(nx,ny,nz) = min(asymtot(nx,ny,nz), 0.999999)
              asymtot(nx,ny,nz) = max(asymtot(nx,ny,nz),-0.999999)
            Endif
c
 130     Continue
c     
         Endif
c
 110    Continue
c
c
c       Compute all the emissivities needed as a function of
c       polarization and surface parameter (wind or soil wetness) 
c
        do npol = 0, 1
            do ny = 1, ngridy
              do nx = 1, ngridx
              
                if(background .eq. 'water') then
                  ! write(*,*) 'water background ' 
                  lambert=.false.
c
c Surface emissivity 
c 
                  call emit(freq(nf), npol, tskin(nx,ny), 
     $                      wind_sfc(nx,ny), umu, 
     &                      emis(nx,ny), ebar(nx,ny))
                else if(background .eq. 'land') then
                  !write(*,*) 'land background ' 
                  lambert=.true.
                  call emit(freq(nf), npol, tskin(nx,ny), 
     $                      0., umu, emis(nx,ny), ebar(nx,ny))
                  emis(nx,ny) = (1.-soilH2O(nx,ny))*0.9 +
     +                              soilH2O(nx,ny)*emis(nx,ny)
                  ebar(nx,ny) = (1.-soilH2O(nx,ny))*0.9+
     +                              soilH2O(nx,ny)*ebar(nx,ny)
                else
                  write(6,*) ' No background surface was chosen '
                  stop
                end if
              end do
            end do
c    
c           Now call the radiative transfer subroutine:  either the
c           plane parallel or slant-path Eddington approximation
c           in this case.
c
            if (slant_path) then
c
c             Apply Eddington calculation to slant paths through
c             model domain.
c
              call eddington_sp(ngridx, ngridy, deltay, umu, nlyr, 
     +              tskin, temp_lev, hgt_lev, kexttot, salbtot, 
     +              asymtot, emis, ebar, lambert, tb)


            else
c
c             Apply Eddington calculation to vertical columns in
c             model domain.
c
              call eddington_pp(ngridx, ngridy, umu, nlyr, tskin, 
     +              temp_lev, hgt_lev, kexttot, salbtot, asymtot, 
     +              emis, ebar, lambert, tb)
            endif
c     
c           Write Tb for each frequency, polarization and surface
c           parameter into the proper output array
c
            do nx = 1, ngridx
              do ny = 1, ngridy
                Tb_out(nx,ny,nf,npol) = tb(nx,ny)
c                
c               Verify that Tb are in bounds (including NaN)
c                                
                if ((Tb_out(nx,ny,nf,npol) .gt.  50.) .and.
     $              (Tb_out(nx,ny,nf,npol) .lt. 350.)) then
                 continue
                else
                 write(*,540) nx,ny,nf,npol,Tb_out(nx,ny,nf,npol)
  540            format('Tb out of bounds @ ',5i5,f7.2)
                stop
                endif
              end do
            end do
            
          end do     ! ends loop over npol
      end do    ! ends loop over nfreq
c
      Return
      End
