      subroutine vapor_pressure(ngridx, ngridy, nlyr, temp_lev, 
     +          press_lev, relhum, avg_pressure, avg_H2Opressure)

c     Calculate average air pressure and vapor pressure in specified
c     layers, given the temperature, pressure, and relative humidity 
c     from cloud-resolving model output.

C+-------+---------+---------+---------+---------+---------+---------+-+
C+----------------------------------------------------------------------

      include    '../GRIDparameters.inc'
      real *4   press_lev(mxgridx,mxgridy,0:mxlyr)
      real *4   temp_lev(mxgridx,mxgridy,0:mxlyr)
      real *4   relhum(mxgridx,mxgridy,mxlyr)
      real *4   avg_pressure(mxgridx,mxgridy,mxlyr)
      real *4   avg_H2Opressure(mxgridx,mxgridy,mxlyr)
     
      real *4   tavg, tc, es, esatvap

      data a0/6.107799961e0/
      data a1/4.436518521e-1/
      data a2/1.428945805e-2/
      data a3/2.650648471e-4/
      data a4/3.031240396e-6/
      data a5/2.034080948e-8/
      data a6/6.136820929e-11/

      do nx = 1, ngridx
        do ny = 1, ngridy
          do nz = 1, nlyr
          
            tavg = 0.5*(temp_lev(nx,ny,nz-1) + temp_lev(nx,ny,nz))
            avg_pressure(nx,ny,nz) = 
     +          (press_lev(nx,ny,nz) - press_lev(nx,ny,nz-1) )/
     +           log(press_lev(nx,ny,nz)/press_lev(nx,ny,nz-1))
            tc = tavg - 273.15
            ES = a0+tc*(a1+tc*(a2+tc*(a3+tc*(a4+tc*(a5+a6*tc)))))
            if (ES .lt. 0.) ES = 0.
            avg_H2Opressure(nx,ny,nz) =  relhum(nx,ny,nz)*ES/100.
          end do
        end do
      end do  

      return
      end       
