      Subroutine param_set_BMCV ( microw, radar, visIR, crosst_x,
     &                            fov_ct_microw, fov_dt_microw,
     &                            fov_ct_radar, fov_dt_radar, wavel,
     &                            fov_ct_visir, fov_dt_visir, tbform )
      Implicit NONE
c
      Include 'BMCVparameters.inc'
c
c Input: 
c    (NONE)
c Outputs: 
c  - sensor parameters and running options
c    microw, radar, visIR, crosst_x, fov_ct_microw, fov_dt_microw,
c    fov_ct_radar, fov_dt_radar, wavel, fov_ct_visir, fov_dt_visir, tbform
c
c 1. Microwave radiometer -------------------------------------------
c
c 1.1 Microwave-radiometer simulation is skipped when microw = .false.
c
      microw = .true.
c
c 1.2 Sensor field of views in [km]*
c    (*: the unit of FOV can be arbitrarily defined but must be shared
c        by "delta_x" and "delta_y".)
c    # of channels are defined by "mxfreq" in "BMCVparameters.inc".
c
c  the cross-track FOV sizes
c
      fov_ct_microw(1) = 36.
      fov_ct_microw(2) = 18.
      fov_ct_microw(3) = 17.
      fov_ct_microw(4) = 9.7
      fov_ct_microw(5) = 4.2
c
c  the down-track FOV sizes
c
      fov_dt_microw(1) = 60.
      fov_dt_microw(2) = 30.
      fov_dt_microw(3) = 27.
      fov_dt_microw(4) = 16.
      fov_dt_microw(5) = 6.8
c
c 2. Radar ---------------------------------------------------------
c
c 2.1 Radar simulation is skipped when radar = .false.
c
      radar = .true.
c
c 2.2 Sensor field of view in [km]*
c    (*: the unit of FOV can be arbitrarily defined but must be shared
c        by "delta_x" and "delta_y".)
c    # of channels are defined by "mxfreq_radar" in "BMCVparameters.inc".
c
c  the cross-track FOV sizes
c
      fov_ct_radar(1) = 4.3
c
c  the down-track FOV sizes
c
      fov_dt_radar(1) = 4.3
c
c 3. Visible and IR radiometer -------------------------------------
c
c 3.1 Visble/IR radiometer simulation is skipped when visIR = .false.
c     
      visIR = .true.
c
c 3.2 Sensor field of view in [km]*
c    (*: the unit of FOV can be arbitrarily defined but must be shared
c        by "delta_x" and "delta_y".)
c    # of channels are defined by "mxwavel" in "BMCVparameters.inc".
c
c  the cross-track FOV size (common to all channels)
c
      fov_ct_visir = 2.1
c
c  the down-track FOV size (common to all channels)
c
      fov_dt_visir = 2.1
c
c 3.3 Channel wavelengths [micron]
c    # of channels are defined by "mxwavel" in "BMCVparameters.inc".
c    Wavelenths are required when radiance is converted to/from Tb.
c
      wavel(1) = 0.62
      wavel(2) = 1.6
      wavel(3) = 3.8 
      wavel(4) = 10.8
      wavel(5) = 12.0
c
c 3.4 Raw radiance or brightness temperature
c  Specify tbform = .true. or .false (true for thermal infrared channels
c  for which the data are stored in Tb) for each channel.
c
c  NOTE: "wavel" and "tbform" need to be specified so that brightness 
c        temperature can be transformed to radiance. This procedure is 
c        necessary for beam convolution because infrared Tb is not
c        linearly related to radiance. Beam-convoluted radiance is
c        converted back to Tb for the channels with "tbform=.true.".
c
      tbform(1) = .false.
      tbform(2) = .false.
      tbform(3) = .false.
      tbform(4) = .true.
      tbform(5) = .true.
c
c 4. General options
c
c 4.1 Satellite-tracking direction
c    If the cross-track direction is parallel to x-axis, cross_t=true.
c    Otherwise cross_t=false.
c
      crosst_x = .true.
c
      Return
      End

