      FUNCTION VLSPC3( PR )
C     VOLUME SPECTRUM OF PARTILE POLYDISPERISON: V(x) = dV / d ln r
C---  HISTORY
C     95. 9.14 Created with parameter packet only
C---  INPUT
C     PR    R(6,4)      Parameter packet
C
C        PR(1,1)=r       Particle radius in cm
C        PR(1,2)=NMODE   Number of mode radius
C        PR(1,3)=rmin    Minimum particle radius in cm
C        PR(1,4)=rmax    Maximum particle radius in cm
C
C        FOR EACH J-th MODE (<= 4)
C
C        PR(2,j): TYPE OF FUNCTION (ITP) FOR THE MODE.
C     ITP=1: POWER LAW
C            PR(3,j)=C, PR(4,j)=R0,  PR(5,j)=P
C            vj = C * (R/R0)**(4-P) if R>R0; = C * (R/R0)**4 if R<R0
C     ITP=2: LOG-NORMAL
C            PR(3,j)=C, PR(4,j)=S,   PR(5,j)=RM
C            vj = C * exp(-(ln(R/RM)/ln(S))**2 / 2)
C     ITP=3: MODIFIED GAMMA
C            PR(3,j)=C, PR(4,j)=ALFA, PR(5,j)=BETA, PR(6,j)=GAMMA
C            vj = C * (R1)**(ALFA+4) exp (-BETA*R1**GAMMA) where R1=R*1.0E4
C     ITP=4: MARSHALL-PALMER
C         dN/dr = N0 * EXP(-lambda*D) , D=2*r
C $$$$$$  MODIFIED by H.MASUNAGA (01/06/21)  $$$$$$
C         PR(3,j) = N0 [cm^-4], PR(4,j) = lambda [cm^-1]
C $$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
C         vj = 4 * PI * r**4 * dN/dr / 3
C---  OUTPUT
C     VLSPC3 RF       dV/d ln r
C$ENDI
C
      PARAMETER ( PI = 3.14159265359879 )

      DIMENSION PR(6,4)

      R = PR(1,1)
      NMODE = PR(1,2) + 0.001
      RMIN = PR(1,3)
      RMAX = PR(1,4)
c
      VLSPC3 = 0.
      DO 101 M = 1 ,NMODE
         ITP = PR(2,M) + 0.001
         IF( ITP .EQ. 2 ) GOTO 4
         IF( ITP .EQ. 3 ) GOTO 5
         IF( ITP .EQ. 4 ) GOTO 6
C     POWER LAW
         IF( R .LT. RMIN  .OR.  R .GT. RMAX ) RETURN
         C = PR(3,M)
         RC = PR(4,M)
         PDNDR = PR(5,M)
         IF( R .LE. RC ) THEN
            PN = 4.0
         ELSE
            PN = 4.0 - PDNDR
         ENDIF
         E1 = PN * LOG(R / RC)
         GOTO 100
C     LOG-NORMAL
    4    IF( R .LT. RMIN  .OR.  R .GT. RMAX ) RETURN
         C = PR(3,M)
         S = PR(4,M)
         RM = PR(5,M)
         E1 = -0.5 * (LOG(R / RM) / LOG(S))**2
         GOTO 100
C     MODIFIED GAMMA
    5    IF( R .LT. RMIN  .OR.  R .GT. RMAX ) RETURN
         R1 = R * 1.0E4
         C = PR(3,M)
         ALF = PR(4,M)
         BET = PR(5,M)
         GAM = PR(6,M)
         E1 = (ALF + 4.) * LOG(R1) - BET * R1**GAM
         GOTO 100
C     MARSHALL-PALMER   !! MODIFIED by H.MASUNAGA
    6    IF( R .LT. RMIN  .OR.  R .GT. RMAX ) RETURN
         Diamtr = R * 2.
C Corrected by H. Masunaga (Aug, 07) (to take into account dD = 2*dr)
         DNDR = PR(3,M) * EXP(-PR(4,M) * Diamtr) * 2
CCC         DNDR = PR(3,M) * EXP(-PR(4,M) * Diamtr)
         VLSPC3 = VLSPC3 + 4.0 * PI * DNDR * R**4 / 3.0
         GOTO 101
  100    IF( E1 .GT. -100.0 ) VLSPC3 = VLSPC3 + C * EXP(E1)
  101 CONTINUE

      RETURN
      END
